@@ -1,5 +1,11 @@
 """Constant values for the Tado component."""
 
+# Api credentials
+CLIENT_ID = "tado-web-app"
+CLIENT_SECRET = (
+    "wZaRN7rpjn3FoNyF5IFuxg9uMzYJcvOoQ8QWiIqS3hfk6gLhVlG57j5YNoZL2Rtc"
+)
+
 # Types
 TYPE_AIR_CONDITIONING = "AIR_CONDITIONING"
 TYPE_HEATING = "HEATING"
@@ -42,8 +48,12 @@ CONST_HORIZONTAL_SWING_MID_RIGHT = "MID_RIGHT"
 CONST_HORIZONTAL_SWING_RIGHT = "RIGHT"
 
 # When we change the temperature setting, we need an overlay mode
-CONST_OVERLAY_TADO_MODE = "NEXT_TIME_BLOCK"  # wait until tado changes the mode automatic
-CONST_OVERLAY_MANUAL = "MANUAL"  # the user has changed the temperature or mode manually
+CONST_OVERLAY_TADO_MODE = (
+    "NEXT_TIME_BLOCK"  # wait until tado changes the mode automatic
+)
+CONST_OVERLAY_MANUAL = (
+    "MANUAL"  # the user has changed the temperature or mode manually
+)
 CONST_OVERLAY_TIMER = "TIMER"  # the temperature will be reset after a timespan
 
 # Heat always comes first since we get the
@@ -82,7 +92,11 @@ TADO_HVAC_ACTION_TO_MODES = {
 }
 
 # These modes will not allow a temp to be set
-TADO_MODES_WITH_NO_TEMP_SETTING = [CONST_MODE_AUTO, CONST_MODE_DRY, CONST_MODE_FAN]
+TADO_MODES_WITH_NO_TEMP_SETTING = [
+    CONST_MODE_AUTO,
+    CONST_MODE_DRY,
+    CONST_MODE_FAN,
+]
 
 DEFAULT_TADO_PRECISION = 0.1
 
